==> peaceful-progression-1.1.0-sources.jar: xen42/peacefulitems/mixin/BrushItemMixin.java <==
package xen42.peacefulitems.mixin;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1440;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_239;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3966;
import net.minecraft.class_8162;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_8162.class)
public class BrushItemMixin extends class_1792 {
	public BrushItemMixin(class_1793 settings) {
		super(settings);
	}
	
	@Shadow
	private class_239 getHitResult(class_1657 user) { return null; }

	@Override
	public class_1269 method_7847(class_1799 stack, class_1657 user, class_1309 entity, class_1268 hand) {
		if (user != null && getHitResult(user).method_17783() == class_239.class_240.field_1331) {
			user.method_6019(hand);
		}
		
		return class_1269.field_21466;
	}

	@Inject(at = @At("HEAD"), method = "usageTick", cancellable = true)
	public void usageTick(class_1937 world, class_1309 user, class_1799 stack, int remainingUseTicks, CallbackInfo info) {
		if (remainingUseTicks >= 0 && user instanceof class_1657 playerEntity) {
			class_239 hitResult = this.getHitResult(playerEntity);
			if (hitResult instanceof class_3966 entityHitResult && hitResult.method_17783() == class_239.class_240.field_1331) {
				if ((this.method_7881(stack) - remainingUseTicks + 1) % 10 == 5) {
					class_1297 entity = entityHitResult.method_17782();
					class_2338 blockPos = entity.method_24515();
					world.method_45447(playerEntity, blockPos, class_3417.field_43155, class_3419.field_15245);
					if (world instanceof class_3218 serverWorld && entity instanceof class_1440 pandaEntity) {
						if (!pandaEntity.method_6545()) {
							pandaEntity.method_6546(true);
							class_1304 equipmentSlot = stack.equals(playerEntity.method_6118(class_1304.field_6171)) ? class_1304.field_6171 : class_1304.field_6173;
							stack.method_7970(1, playerEntity, equipmentSlot);
						}
					}
				}
				info.cancel();
			}
		}
	}
}

==> peaceful-progression-1.1.1-sources.jar: xen42/peacefulitems/mixin/BrushItemMixin.java <==
package xen42.peacefulitems.mixin;

import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1297;
import net.minecraft.class_1304;
import net.minecraft.class_1309;
import net.minecraft.class_1440;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_239;
import net.minecraft.class_3218;
import net.minecraft.class_3417;
import net.minecraft.class_3419;
import net.minecraft.class_3966;
import net.minecraft.class_8162;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;

@Mixin(class_8162.class)
public class BrushItemMixin extends class_1792 {
	public BrushItemMixin(class_1793 settings) {
		super(settings);
	}
	
	@Shadow
	private class_239 getHitResult(class_1657 user) { return null; }

	@Override
	public class_1269 method_7847(class_1799 stack, class_1657 user, class_1309 entity, class_1268 hand) {
		if (user != null && getHitResult(user).method_17783() == class_239.class_240.field_1331) {
			user.method_6019(hand);
		}
		
		return class_1269.field_21466;
	}

	@Inject(at = @At("HEAD"), method = "usageTick", cancellable = true)
	public void usageTick(class_1937 world, class_1309 user, class_1799 stack, int remainingUseTicks, CallbackInfo info) {
		if (remainingUseTicks >= 0 && user instanceof class_1657 playerEntity) {
			class_239 hitResult = this.getHitResult(playerEntity);
			if (hitResult instanceof class_3966 entityHitResult && hitResult.method_17783() == class_239.class_240.field_1331) {
				if ((this.method_7881(stack, user) - remainingUseTicks + 1) % 10 == 5) {
					class_1297 entity = entityHitResult.method_17782();
					class_2338 blockPos = entity.method_24515();
					world.method_45447(playerEntity, blockPos, class_3417.field_43155, class_3419.field_15245);
					if (world instanceof class_3218 serverWorld && entity instanceof class_1440 pandaEntity) {
						if (!pandaEntity.method_6545()) {
							pandaEntity.method_6546(true);
							class_1304 equipmentSlot = stack.equals(playerEntity.method_6118(class_1304.field_6171)) ? class_1304.field_6171 : class_1304.field_6173;
							stack.method_7970(1, playerEntity, equipmentSlot);
						}
					}
				}
				info.cancel();
			}
		}
	}
}
